@@ -14,6 +14,13 @@ except:
     import simplejson as json
 
 
+class HgException(Exception):
+    """Exception class allowing a exit_code parameter and member
+    to be used when calling Mercurial to return exit code"""
+    def __init__(self, msg, exit_code=None):
+        super(HgException, self).__init__(msg)
+        self.exit_code = exit_code
+        
 class Revision(object):
     """A representation of a revision.
     Available fields are::
@@ -50,8 +57,8 @@ class Repo(object):
         self.cfg = False
         self.user = user
         self._env = os.environ
-        self._env['LANG'] = 'en_US'
- 
+        self._env[str('LANG')] = str('en_US')
+		
     def __getitem__(self, rev=slice(0, 'tip')):
         """Get a Revision object for the revision identifed by rev
            rev can be a range (6c31a9f7be7ac58686f0610dd3c4ba375db2472c:tip)
@@ -71,8 +78,8 @@ class Repo(object):
 
         if proc.returncode:
             cmd = (" ".join(["hg", "--cwd", self.path] + list(args)))
-            raise Exception("Error running %s:\n\tErr: %s\n\tOut: %s\n\tExit: %s" 
-                            % (cmd,err,out,proc.returncode))
+            raise HgException("Error running %s:\n\tErr: %s\n\tOut: %s\n\tExit: %s" 
+                            % (cmd,err,out,proc.returncode), exit_code=proc.returncode)
         return out
 
     def hg_init(self):
@@ -120,9 +127,13 @@ class Repo(object):
         cmd = ['tags']
         output = self.hg_command(*cmd)
         res = {}
+        reg_expr = "(?P<tag>.+\S)\s+(?P<rev>\d+):(?P<changeset>\w+)"
+        pattern = re.compile(reg_expr)
         for row in output.strip().split('\n'):
-            tag, changeset = row.split() # tip  5:aaaaaaaaaa
-            res[tag] = changeset.split(':')[1]
+            match = pattern.match(row)
+            tag = match.group("tag")
+            changeset = match.group("changeset")
+            res[tag] = changeset
         return res
 
     def hg_heads(self, short=False):
