@@ -295,10 +295,12 @@ class TestHgAPI(unittest.TestCase):
         original_tip = self.repo['tip'].node
         self.repo.hg_tag('mytag', 'othertag')
         self.repo.hg_tag('mytag2', rev=1)
+        self.repo.hg_tag('long mytag3', rev=2)
         tags = self.repo.hg_tags()
         self.assertEqual(tags, {'mytag': original_tip,
             'othertag': original_tip,
             'mytag2': self.repo[1].node,
+            'long mytag3': self.repo[2].node,
             'tip': self.repo[-1].node})
 
     def test_220_LogWithBranch(self):
@@ -318,7 +320,13 @@ class TestHgAPI(unittest.TestCase):
         self.assertEquals(len(diffs), 1)
         self.assertEquals(diffs[0]['filename'], 'file.txt')
         self.assertTrue('+even more stuff' in diffs[0]['diff'])
-
+        
+    def test_250_ExitCode(self):
+        try:
+            self.repo.hg_update('notexistingref')
+        except hgapi.HgException as update_ex:
+            self.assertNotEquals(update_ex.exit_code, None)
+            self.assertNotEquals(update_ex.exit_code, 0)
 def test_doc():
     #Prepare for doctest
     os.mkdir("./test_hgapi")
@@ -336,4 +344,4 @@ if __name__ == "__main__":
     try:
         test_doc()
     finally:
-        unittest.main()
\ No newline at end of file
+        unittest.main()
